% cyst_plot_map_sample.m

clear;

fig_pos = [135   334   499   561];
% Colorbar/ColorbarText position.
d_yc=-1.15;
ky_tcb=-0.17;
kc=0.85;
cb_dw=0.4;
% For Axes position.
d_x=-0.036;
d_y=-0.035;
k=1.11;

% Draw coast line.
drawCoast='yes';
%drawCoast='no';

% ---- Land, ocean, isobaths.
%bnd_color=[0.71 0.66 0.43];
land_color=[0.8 0.8 0.66];
ocean_color=[1 1 1];
isobaths_color=[0.8 0.8 0.8];
color_lbl=[0.5 0.5 0.5];
fnt_name_lbl_isobath='symbol';
fnt_lbl_isobath=6;
marker_size_land=1;

%********************
% Map limits.
%********************
latmin = 41.5;
latmax = 45.5;
lonmax = 71;
lonmin = 65.5;
% Calculate relation relyx = axisy/axisx (for PlotBoxAspectRatio)
weg = 111*cos(pi*(latmin+(latmax-latmin)/2)/180);% Weight of one degree longitude
xc = (lonmax-lonmin)*weg;                        % Longitude, km
yc = (latmax-latmin)*111;                        % Latitude, km
relyx = yc/xc;
%********************
% Meshgrid limits.
%********************
meshLonMin=lonmin;
meshLonMax=lonmax;
meshLatMin=latmin;
meshLatMax=latmax;
% Choose meshgrid interval:
meshInt=0.025;
%meshInt=0.005;

%@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@
%@@@@@@@@@@@@@  LOAD COLORMAP PALETTE @@@@@@@@@@@@@@@
%@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@
load palet_10_colors;
cmap=palet_10_colors;
vv=[0 25 50 100 200 300 500 700 1000 2000 3000];

%@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@
%@@@@@@@@@@@@@@    LOAD CYST DATA  @@@@@@@@@@@@@@@@@@
%@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@
load EN486_2010_cystsv5_distrib_w.txt;
d_a=EN486_2010_cystsv5_distrib_w;
% Columns, names.
colSt=1;
colSt_id=2;
colLon=7;
colLat=8;
colCyst=9;
cyst_name='Sediment layer 1cm'; %
cr_name='R/V Endeavor EN486';
cr_date='October (13-23) 2010';
cr_id='en486';
cyst_units='cysts/cm^3';
j_title=['Cyst Counts, ' cyst_name];
j_label=['Cyst (' cyst_units ')'];

%********************
% Remove 'bad' data.
%********************
r_bad=find(isnan(d_a(:,colCyst)));
d_a(r_bad,:)=[];

%********************
% Set figure and axes.
%********************
figure;
set(gcf,'color',[1 1 1],'position',fig_pos,...
    'paperPositionMode','auto');
colormap(cmap);
axPos=get(gca,'position');
set(gca,'position',[axPos(1)+axPos(3)*(d_x) axPos(2)+axPos(4)*d_y axPos(3)*k axPos(4)*k]);

%********************
% Cyst and location data.
%********************
LON_map = -d_a(:,colLon);
LAT_map = d_a(:,colLat);
PAR_map = d_a(:,colCyst);

%********************
% Meshgrid and griddata.
%********************
[LONi,LATi] = meshgrid(meshLonMin:meshInt:meshLonMax,meshLatMin:meshInt:meshLatMax);
PARi = griddata(LON_map,LAT_map,PAR_map,LONi,LATi,'linear');

%*************************
% Calculate scaled Z matrix.
%*************************
[Z_new,cval] = f_oc412_spec_scale(PARi,vv);

%*************************
% Plot filled contours.
%*************************
[c,h]=contourf(LONi,LATi,Z_new,cval);
set(h,'edgeColor','none');
%!!!!!!!!!
% USE -0.000000001: without this the colors are sometimes incorrect
% (dessapear or shift)
caxis([min(cval-0.000000001 ) max(cval-0.000000001)]);
%!!!!!!!!!
%caxis([min(cval) max(cval)]);
hold off;

%*************************
% COLORBAR.
%*************************
h1 = colorbar('horiz');
aPos = get(h1,'Position');
d_xc=(1-kc)/2;
set(h1,'Position',[aPos(1,1)+aPos(1,3)*d_xc aPos(1,2)+aPos(1,4)*d_yc aPos(1,3)*kc aPos(1,4)*cb_dw]);
% Put scaled values to  colorbar ticks and primary data values to colorbar ticks labels.
set(h1,'xtick',cval,'xticklabel',vv,'xLim',[min(cval) max(cval)],...
    'xAxisLocation','bottom',...
    'Fontsize',9,'ticklength',get(h1,'ticklength')*1.9);
tlb=get(h1,'xticklabel');
tlb_end_new=['>' num2str(vv(end-1))];
tlb(end,:)=[];
tlb=strvcat(tlb,tlb_end_new);
set(h1,'xticklabel',tlb);
text(lonmax-range([lonmax lonmin])*0.5,latmin+range([latmax latmin])*ky_tcb,j_label,...
    'FontSize',9,'horizontalAlignment','center');

%##########################################################
%################  MAP WHITENING  #########################
%##########################################################
map_whitening='yes';
%map_whitening='no';
if strcmp(map_whitening,'yes')
    whiten_cont =[70.41         41.82
        70.33         42.06
        70.19         42.20
        69.94         42.27
        69.71         42.29
        69.36         42.39
        69.09         42.45
        68.77         42.68
        68.50         42.88
        68.19         43.01
        67.72         43.11
        67.42         43.23
        66.84         43.43
        66.81         43.74
        66.79         44.00
        66.75         44.13
        66.56         44.31
        66.31         44.47
        66.04         44.64
        65.91         44.72
        65.71         44.82
        66.37         42.45
        70.38         41.80];
    whiten_cont=[whiten_cont;whiten_cont(1,:)];
    whiten_cont_2 =[69.92         43.63
        69.51         43.76
        68.95         43.94
        68.70         44.00
        68.51         44.05
        68.37         44.11
        68.24         44.22
        68.14         44.36
        67.77         44.41
        67.41         44.54
        67.27         44.58
        66.96         44.73
        66.83         44.88
        66.82         44.94
        66.69         45.03
        69.54         44.97
        70.46         43.56];
    whiten_cont_2=[whiten_cont_2;whiten_cont_2(1,:)];
    hold on;
    if ~isempty(whiten_cont), ...
            patch(whiten_cont(:,1),whiten_cont(:,2),ocean_color,'faceColor',ocean_color,'edgeColor','none'); end
    if ~isempty(whiten_cont_2), ...
            patch(whiten_cont_2(:,1),whiten_cont_2(:,2),ocean_color,'faceColor',ocean_color,'edgeColor','none'); end
    hold off;
end
%##########################################################
%##########  PLOT LAND and BATHYMETRY #####################
%##########################################################
%*********************
% Plot Land.
%*********************
if strcmp(drawCoast,'yes')
    load cyst_LAND;
    r_land=find(Z(:,1)>=0);
    LAT_land=LAT_bath(r_land);
    LON_land=LON_bath(r_land);
    dd_land_lat=0;
    dd_land_lon=0;
    dd_land_lon_1=0.0045;
    hold on;
    r_remove=find(LON_land(:)<=lonmin+dd_land_lon | LON_land(:)>=lonmax-dd_land_lon_1 | ...
        LAT_land(:)<=latmin+dd_land_lat | LAT_land(:)>=latmax-dd_land_lat);
    LAT_land(r_remove)=[];
    LON_land(r_remove)=[];
    plot(LON_land,LAT_land,'o','markerfaceColor',land_color,'markeredgeColor',land_color,'markersize',marker_size_land);
    hold off;
    %*********************
    % Plot bathymetry.
    %*********************
    hold on;
    iso_list=[60 100 200 300];
    count_i=0;
    for isoNum=iso_list
        count_i=count_i+1;
        switch isoNum
            case 60
                lbl_pos=[70.1801   40.5509
                    68.2180   40.7626
                    66.00         43.20
                    65.85         45.14];
            case 100
                lbl_pos=[69.2407   41.4338
                    68.4995   40.3777
                    65.8318   42.4793
                    66.11         43.13 ];
            case 200
                lbl_pos=[ 69.2332   42.1094
                    68.2777   42.0966
                    67.15     43.21];
            case 300
                lbl_pos=[65.6843   41.9256
                    66.5142   42.3831];
        end
        p=['load isobath_' num2str(isoNum) 'm'];
        eval(p);
        p=['d_i=isobath_' num2str(isoNum) 'm;'];
        eval(p);
        d_i(:,1)=-d_i(:,1);
        h(count_i)=plot(d_i(:,1),d_i(:,2),'-','color',isobaths_color,'linewidth',0.3);
        for t_pos=1:size(lbl_pos,1)
            t_pos=lbl_pos(t_pos,:);
            r_out=find(t_pos(:,1)<lonmin | t_pos(:,1)>lonmax | t_pos(:,2)<latmin | t_pos(:,2)>latmax);
            if isempty(r_out)
                t_i=text(t_pos(1),t_pos(2),[num2str(isoNum)],'horizontalAlignment','center',...
                    'verticalAlignment','middle','fontname',fnt_name_lbl_isobath,...
                    'Fontsize',fnt_lbl_isobath,'color',color_lbl,'fontAngle','it');
            end
        end
    end % For for isoNum=iso_list
    hold off;
end % For if strcmp(drawCoast,'yes')
%##########################################################

%********************
% Plot station locations.
%********************
hold on;
plot(LON_map,LAT_map,'ko','markersize',3)
hold off;

%******************************
% Set axes properties.
%******************************
axis([lonmin lonmax latmin latmax]);
set(gca,'FontSize',9,'xdir','reverse',...
    'box','on','PlotBoxAspectRatio',[1 relyx*1 1],...
    'ticklength',get(gca,'ticklength')*0.6,'tickdir','out');
xlabel('Longitude (\circW)','FontSize',9);
ylabel('Latitude (\circN)','FontSize',9);
str_title(1)={[j_title]};
str_title(2)={[cr_name ', ' cr_date]};
title(str_title,'FontSize',10,'verticalAlignment','bottom');



