function [timeEffect,stationEffect,ia,ia2,sigma2]=sub_fitModelAnovaUnbalanced(data,scenario)

% [timeEffect,stationEffect,ia]=fitModelAnovaUnbalanced(data,scenario)
%
% fits unbalanced 2 way anova
% just removes rows in the design matrix that correspond to missing data
%
% data = structure of all cyst data
% scenario = a vector of station numbers whos cell counts are assumed known
%
% timeEffect = vector of time effects      -| from 2 way anova
% station Effect = vector of time effects  -|
% ia = vector of indices for stations whos cell counts we need to estimate
% ia2 = vector of indices for stations whos cell counts we know


% find locations of stations we need to use.
missingStations = setdiff(data.station,scenario);
[C,ia,ib] = intersect(data.station,missingStations); % ia = index in data.station
[C2,ia2,ib2] = intersect(data.station,scenario); % stations to keep in the fit
currentYearData = data.cellCounts(ia,end);

nT = length(data.years);
nJ = length(data.station);
nMissing = length(missingStations); % these are really unsampled stations

% create the complete design matrix as if no data were missing.  a complete
% 2 way anova balanced design with 1 observation per cell
XTblock=[];
rowtemp = zeros(1,nT);
XJblock = [eye(nJ-1);[repmat(-1,1,nJ-1)]];
for i = 1:nT
    for j = 1:nJ
        row = rowtemp;
        row(i) = 1;
        XTblock = [XTblock;row];
    end
end
X = [XTblock,repmat(XJblock,nT,1)];
[ndp,numparams] = size(X);
XTemp = X;


% now we need to remove rows that correspond to missing stations
% we add a row of nans to data we dont have
irow = 0;
YMAT=zeros(nT*nJ,1);
for iy = 1:nT % years
    for jS = 1:nJ % station
        irow = irow+1;
        YMAT(irow) = log(data.cellCounts(jS,iy)+1);
        % if nan in cell count then remove from design matrix
        if isnan(data.cellCounts(jS,iy))
            XTemp(irow,:) = nan(1,numparams);
        end
    end
end
% we select only rows that do not have nans
% This will be the design matrix in the regression
ind = ~isnan(XTemp(:,1));
XMAT = XTemp(ind,:);
Y = YMAT(ind);

% number of year station combinations unsampled relative to a balanced design
nMissing = sum(~ind) 

% perform regression to obtain parameter estimates
betas = inv(XMAT'*XMAT)*XMAT'*Y;

timeEffect = betas(1:nT)';
stationEffect = [betas((nT+1):end);-sum(betas((nT+1):end))];

sigma2 = sum(power(Y-XMAT*betas,2))/(nT*nJ - nMissing - nT - nJ + 1)
