function data = mainCystApplication

% Unbalanced 2 way anova.
% Data are the cyst counts from Bruce Keafers cruise
% We wish to predict the cyst map for layer = 'top'
%
% Too many missing data to perform this on bottom layer. We would need to
% trim the data to do this.
%
% we take the data that Bruce Keafer sampled on his 2013 cruise and fit the model
% to get predictions at the other stations to then obain a predicted
% spatial map.

close all % close all open windows
%% reads in the cleaned up version of Cyst data and plots the layers.
[dataTop,dataBottom] = sub_readDataClean;
data = dataTop; % use top layer data
%.station
%.long
%.lat 
%.cellCounts
%.years 
%.label


%% predict the spatial map
% to plot the spatial map in the most recent year we need the obsevations from 
% the cruise and then the estimated values at the stations not sampled.
% We obtain estimates by fitting the seperable model by means of a 2 way
% unbalanced anova

% stations sampled in current year. treated as known
ind = ~isnan(data.cellCounts(:,end));
scenario = data.station(ind); % sampling stations with observations

%h = gca;
% form fittted data.
specs.LON_map = -data.long; % longitude of data points
specs.LAT_map = data.lat; % latitude of data points

% create labels for plot
labels.cr_name='';
labels.j_label=[''];


% fit the model
% use all of the data to fit. 2 way anova, unbalanced design. 1 obs. per
% cell with several cells missing data

[timeEffect,stationEffect,indexMissing,indexSampled,sigma2] = sub_fitModelAnovaUnbalanced(data,scenario);
% we now predict the missing stations and create a spatial map.

% these are fitted values for all stations
fittedCounts = timeEffect(end) + stationEffect;
% however we have data for some of these so we dont need the fitted
% values. use the data instead
observedAndFittedCounts = log(data.cellCounts(:,end)+1);

% now we need to plot surface
PAR_map = exp(fittedCounts + sigma2/2);
% replace the sampled locations with their data values
PAR_map(indexSampled) = data.cellCounts(indexSampled,end);

[specs,labels] = sub_plotSingleMap(specs,labels,PAR_map);
hold on
plot(-data.long(indexSampled),data.lat(indexSampled),'ko','markersize',3,'markerface','k')
plot(-data.long(indexMissing),data.lat(indexMissing),'ko','markersize',2,'markerface','k')
text(-data.long(indexMissing),data.lat(indexMissing),num2str(data.station(indexMissing)),'fontsize',8)
%% note:
% you will see that the map does not extend out to station 45 or 46. This
% is because of "map whitening" found in OLGA_post_cyst_plot_map_specs.m
% i am not sure what this does, you'll need to ask Olga. However the actual
% predictions are stored in the output file out.txt

% plot time effect
figure
plot(data.years,timeEffect,'k')
xlabel('Time')
ylabel('Effect')

%% writes model fit to a file called out.txt
% note that stations that were sampled use predicted=sampled
str = '%5.0f %10.5f %10.5f %10.0f %10.0f\n';
fid = fopen('out.txt','w');
fprintf(fid,'%s \n','station, lat,       long,     sampled data, predicted');
out = [data.station,data.lat,data.long,data.cellCounts(:,end),PAR_map]';
fprintf(fid,str,out);
fclose('all');


