function [dataTop,dataBottom] = sub_readDataClean;

% reads in the "cleaned up" version of the cyst data from 2004 - present
% The range of data to be read need to change each year %line 23
% THE FORMAT OF THE EXCEL FILE IS VERY IMPORTANT
%
% it is then sorted into a format to be used for analysis
% 
% dataTop are the top 0-1cm data 
% dataBottom are the 1-3cm data 
% All stations are used including staions with letters in their name.
% Note: that all replicate samples should be averaged in the main file
% All station names should be of the form NN or NNL (number, number, letter)
% eg. 28D

% dummy variable used for station matching
stLetter = cell({'A', 'B', 'C', 'D', 'E', 'F', 'G', 'H', 'I'});

% Reads in an excel worksheet
% we only use rawYr. this is raw data in a cell 
%%%%%% THE BOUND WILL NEED TO CHANGE DEPENDING ON THE DATA FILE %%%%%%%%%%%
%%%% CHANGE a7:g1049 TO REFLECT DATA IN EXCEL FILE
[shit1, shit2, rawYr] = xlsread('sampleData.xlsx','DATA','a7:g1049');

%% pick out unique station numbers
ic = 0;
for ii = 1:size(rawYr,1)
    if isnan(rawYr{ii,1})
        continue
    else
        ic = ic + 1;
        cellArray = regexp(rawYr{ii,1},'_','split');
        stationList{ic} = cellArray{1};
    end
end

% unique set of stations in data set
stations = unique(stationList);
nStations = length(stations);

%% pick out 5 columns of data from Bruce's data file
% We will choose station number(1), lat(2), long(3), 0-1cm(4), & 1-3 cm(5).
ic = 0;
jc = 0;
for iline= 1:size(rawYr,1)
    % looks at file line by line
    d = rawYr(iline,:);

    if isnan(d{1})
        continue
    end
    % splits the stationNumber_year entry
    cellArray2 = regexp(d(1),'_','split');
    % selects the stationNumber this will be a text since some contain
    % letters
    stNum = cellArray2{1}(1); 

     % we process all station names 
        ic = ic + 1;
        yr = str2double(cellArray2{1}(2));
        long = cell2mat(d(4)); % 0-1 cm data
        if ischar(long)
            long = str2num(long);
        end
        lat = cell2mat(d(5));
        if ischar(lat)
            lat = str2num(lat);
        end
        top = cell2mat(d(6));
        if ischar(top)
            top = str2num(top);
        end
        bottom = cell2mat(d(7));
        if ischar(bottom)
            bottom = str2num(bottom);
        end
        % We convert stationNames that have a letter in them to have a
        % decimal. eg. 28D = 28.4 28B = 28.2

        if ~isnan(str2double(stNum)) % station number is numeric
            tempData(ic,:)=[str2double(stNum),yr,long,lat,top,bottom];
        else % has a letter in name
            stNum = char(stNum);
            letterLoc = regexpi(stNum,'\D');
            numericPart = str2num(stNum(1:(letterLoc-1)));

            if ~isequal(length(letterLoc),1)
                error([stNum ,' has more than 1 letter in its name '])
            else                
                decimalPart = find(strcmp(upper(stNum(letterLoc)),stLetter));
            end
            stationNum = str2num([num2str(numericPart),'.',num2str(decimalPart),'0']);
            tempData(ic,:)=[stationNum,yr,long,lat,top,bottom];
        end

end


%% reorganize data
% to form nStations x 3+nYr matrix for top layer
% and nStations x 3+nYr matrix for bottom layer
% eg.  station, long, lat, 2004 2005, 2006, ..., currentYr
years = unique(tempData(:,2))';
cols = [4:4+length(years)];
uniqueStations = unique(tempData(:,1));

% loop over unique stations
for iSt = 1:length(uniqueStations)
   ind = (tempData(:,1) == uniqueStations(iSt));
   % selects data for that station over all years
   useData = tempData(ind,:);
   [nr,nc] = size(useData);
   % we require the same lat and long for each station over time. We take
   % the mean lat and long to represent this location
   long = nanmean(useData(:,3));
   lat = nanmean(useData(:,4));
   dataT(iSt,1) = uniqueStations(iSt);
   dataT(iSt,2) = long;
   dataT(iSt,3) = lat;
   % same station id and location for Top and Bottom layer data
   dataB(iSt,[1:3]) = dataT(iSt,[1:3]);
   % columns 4 - 12 are year counts
   
   % checks to make sure no duplicate years.
   if ~isequal(nr,length(unique(useData(:,2))))
       display('replicate data in station number ')
       uniqueStations(iSt)
   end
   
   % goes through each year for given station and records cell count
   dataT(iSt,[4:end]) = nan;
   dataB(iSt,[4:end]) = nan;
   for iY = 1:nr
       wYr = useData(iY,2);
       col = cols(wYr == years);
       dataT(iSt,col) = useData(iY,5);
       dataB(iSt,col) = useData(iY,6);
   end
 
end

% formats to a structure
% this is the format the data need to be in to run the analysis and plot
% the maps.
dataTop.station = dataT(:,1);
dataTop.long = dataT(:,2);
dataTop.lat = dataT(:,3);
dataTop.cellCounts = dataT(:,4:end);
dataTop.years = years;
dataTop.label = {'0-1 cm'};

dataBottom.station = dataB(:,1);
dataBottom.long = dataB(:,2);
dataBottom.lat = dataB(:,3);
dataBottom.cellCounts = dataB(:,4:end);
dataBottom.years = years;
dataBottom.label = {'1-3 cm'};
